/*:
 [Previous](@previous)

 ## Full example: A conic gradient view, masked with a circular maskView

 Provides controls to toggle tint adjustment, and a fun little animation :)

 &copy; Copyright 2018 - Dave Lyon and Traboule Software

 */
import PlaygroundSupport
import UIKit

class CircleGradientViewController : UIViewController {

    override func loadView() {
        let view = ConicGradientView()

        view.colors = [ .orange, .purple, .blue, .red, .orange]

        let circleView = CircleView(frame: view.layoutMarginsGuide.layoutFrame)
        view.mask = circleView

        self.view = view

        navigationItem.title = "Tinted Circular Conic Gradient"

        navigationItem.leftBarButtonItem = UIBarButtonItem(barButtonSystemItem: .pause, target: self, action: #selector(toggleTintAdjustmentMode))

        navigationItem.rightBarButtonItem = UIBarButtonItem(barButtonSystemItem: .play, target: circleView, action: #selector(CircleView.bounce))
    }

    @objc func toggleTintAdjustmentMode() {
        if let window = navController.view.window {
            let currentMode = window.tintAdjustmentMode

            switch currentMode {
            case .normal, .automatic:
                window.tintAdjustmentMode = .dimmed
            case .dimmed:
                window.tintAdjustmentMode = .normal
            }
        }
    }

    override func viewWillLayoutSubviews() {
        super.viewWillLayoutSubviews()
        view.mask?.bounds = view.layoutMarginsGuide.layoutFrame
    }
}

// Present the view controller in the Live View window
let navController = UINavigationController(rootViewController: CircleGradientViewController())

PlaygroundPage.current.liveView = navController

navController.view.window?.backgroundColor = UIColor(white: 0.47, alpha: 1)
