import UIKit

// Copyright 2018 - Dave Lyon and Traboule Software


public class CircleView: UIView {

    override public class var layerClass: AnyClass {
        return CAShapeLayer.self
    }

    var shapeLayer: CAShapeLayer {
        return self.layer as! CAShapeLayer
    }

    override public func layoutSubviews() {
        shapeLayer.frame = bounds
        shapeLayer.fillColor = UIColor.white.cgColor

        // For simplicity, we'll just assume this is iPhone in portrait and center a circle
        var bbox = CGRect(origin: frame.origin, size: CGSize(width: frame.width, height: frame.width))
        bbox.origin.y = center.y - (bounds.width / 2)

        shapeLayer.path = UIBezierPath(ovalIn: bbox).cgPath

        super.layoutSubviews()
    }

    @objc public func bounce() {
        let downAnimator = UIViewPropertyAnimator(duration: 1.0, curve: UIView.AnimationCurve.easeInOut) {
            self.transform = CGAffineTransform(translationX: 0, y: 125.0)
        }

        let centeringAnimator = UIViewPropertyAnimator(duration: 1.0, curve: UIView.AnimationCurve.easeInOut) {
            self.transform = CGAffineTransform(translationX: 0, y: 0)
        }

        let upAnimator = UIViewPropertyAnimator(duration: 1.0, curve: UIView.AnimationCurve.easeInOut) {
            self.transform = CGAffineTransform(translationX: 0, y: -125.0)
        }

        downAnimator.addCompletion { _ in
            centeringAnimator.startAnimation()
        }

        centeringAnimator.addCompletion { _ in
            upAnimator.startAnimation()
        }

        upAnimator.addCompletion { _ in
            UIViewPropertyAnimator.runningPropertyAnimator(withDuration: 1.0, delay: 0, options: [], animations: {
                self.transform = CGAffineTransform(translationX: 0, y: 0)
            })
        }

        downAnimator.startAnimation()
    }
}
